==> Flask-MIME-Encoders-0.1.2.zip: Flask-MIME-Encoders-0.1.2/README.md <==
# [Flask-MIME-Encoders](https://github.com/salsita/flask-mime-encoders) <a href='https://github.com/salsita'><img align='right' title='Salsita' src='https://www.google.com/a/cpanel/salsitasoft.com/images/logo.gif?alpha=1' /></a>

Extensible Flask MIME encoders and decoders.

[![Latest Version](https://pypip.in/version/Flask-MIME-Encoders/badge.svg)]
(https://pypi.python.org/pypi/Flask-MIME-Encoders/)
[![Downloads](https://pypip.in/download/Flask-MIME-Encoders/badge.svg)]
(https://pypi.python.org/pypi/Flask-MIME-Encoders/)
[![Supported Python versions](https://pypip.in/py_versions/Flask-MIME-Encoders/badge.svg)]
(https://pypi.python.org/pypi/Flask-MIME-Encoders/)
[![License](https://pypip.in/license/Flask-MIME-Encoders/badge.svg)]
(https://pypi.python.org/pypi/Flask-MIME-Encoders/)


## Supported Platforms

* [Python](http://www.python.org/) >= 2.6, 3.3
* [Flask](http://flask.pocoo.org/) >= 0.5


## Get Started

Install using [pip](https://pip.pypa.io/) or [easy_install](http://pythonhosted.org/setuptools/easy_install.html):
```bash
pip install Flask-MIME-Encoders
easy_install Flask-MIME-Encoders
```

## Features

- Provide MIME encoders registry containing loaded MIME encoder classes.
  - Provide standard Flask JSON encoder.
  - Provide extended Flask JSON encoder with ISO8601 date/time format support.


## Changelog

### 0.1.2

#### Fixes

- Fix JSON encoder issues.
- Fix package setup on python 3.

### 0.1.1

#### Fixes

- Fix package setup to not require dependencies preinstalled.

### 0.1.0

#### Features

- Initial release.

==> Flask-MIME-Encoders-0.1.3.zip: Flask-MIME-Encoders-0.1.3/README.md <==
# [Flask-MIME-Encoders](https://github.com/salsita/flask-mime-encoders) <a href='https://github.com/salsita'><img align='right' title='Salsita' src='https://www.google.com/a/cpanel/salsitasoft.com/images/logo.gif?alpha=1' /></a>

Extensible Flask MIME encoders and decoders.

[![Version](https://img.shields.io/github/tag/salsita/flask-mime-encoders.svg?label=version)]
(https://github.com/salsita/flask-mime-encoders/tags)
[![PyPI package](https://img.shields.io/pypi/v/Flask-MIME-Encoders.svg?label=pypi+package)]
(https://pypi.python.org/pypi/Flask-MIME-Encoders/)
[![Downloads](https://img.shields.io/pypi/dm/Flask-MIME-Encoders.svg)]
(https://pypi.python.org/pypi/Flask-MIME-Encoders/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/Flask-MIME-Encoders.svg)]
(https://pypi.python.org/pypi/Flask-MIME-Encoders/)
[![License](https://img.shields.io/pypi/l/Flask-MIME-Encoders.svg)]
(https://pypi.python.org/pypi/Flask-MIME-Encoders/)


## Supported Platforms

* [Python](http://www.python.org/) >= 2.6, 3.3
* [Flask](http://flask.pocoo.org/) >= 0.5


## Get Started

Install using [pip](https://pip.pypa.io/) or [easy_install](http://pythonhosted.org/setuptools/easy_install.html):
```bash
pip install Flask-MIME-Encoders
easy_install Flask-MIME-Encoders
```

## Features

- Provide MIME encoders registry containing loaded MIME encoder classes.
  - Provide standard Flask JSON encoder.
  - Provide extended Flask JSON encoder with ISO8601 date/time format support.


## Changelog

### 0.1.3

#### Fixes

- Fix JSON encoder issues.


### 0.1.2

#### Fixes

- Fix JSON encoder issues.
- Fix package setup on Python 3.


### 0.1.1

#### Fixes

- Fix package setup to not require dependencies preinstalled.


### 0.1.0

#### Features

- Initial release.
